==> pk-select-1.2.0.tgz: package/src/MenuItem.js <==
/* eslint-disable react/forbid-prop-types */
/* eslint-disable react/require-default-props */
/* eslint-disable react/jsx-filename-extension */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable react/no-find-dom-node */
import React, { Component } from 'react';
import scrollIntoView from 'dom-scroll-into-view';
import { findDOMNode } from 'react-dom';
import PropTypes from 'prop-types';

class MenuItem extends Component {
  componentDidUpdate() {
    const {
      activeIndex,
      position,
      menuContainer,
      autoScroll
    } = this.props;
    if (!menuContainer) return;
    if (activeIndex === position && autoScroll) {
      const container = findDOMNode(this);
      setTimeout(() => {
        scrollIntoView(container, menuContainer, {
          alignWithTop: false,
          offsetBottom: 5,
          onlyScrollIfNeeded: true
        });
      }, 0);
    }
  }

  beforeItemClick = e => {
    e.preventDefault();
    let { onClick } = this.props;
    onClick();
  };

  render() {
    const {
      position,
      activeIndex,
      selected,
      label
    } = this.props;
    return (
      <div
        role='button'
        tabIndex='0'
        className={`pk-select--dropdown_item has-hover-effect${(activeIndex === position) ? ' item-active' : ''}${selected ? ' item-selected' : ''}`}
        onClick={this.beforeItemClick}
      >
        <span className='pk-select--dropdown_item-text'>{label}</span>
      </div>
    )
  }
}

MenuItem.propTypes = {
  position: PropTypes.number,
  activeIndex: PropTypes.number,
  selected: PropTypes.bool,
  label: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  menuContainer: PropTypes.any,
  onClick: PropTypes.func,
  autoScroll: PropTypes.bool,
};

export default MenuItem;

==> pk-select-1.2.4.tgz: package/src/MenuItem.js <==
/* eslint-disable react/forbid-prop-types */
/* eslint-disable react/require-default-props */
/* eslint-disable react/jsx-filename-extension */
/* eslint-disable jsx-a11y/click-events-have-key-events */
/* eslint-disable react/no-find-dom-node */
import React, { Component } from 'react'
import scrollIntoView from 'dom-scroll-into-view'
import { findDOMNode } from 'react-dom'
import PropTypes from 'prop-types'

class MenuItem extends Component {
  componentDidUpdate() {
    const {
      activeIndex,
      position,
      menuContainer,
      autoScroll
    } = this.props
    if (!menuContainer) return
    if (activeIndex === position && autoScroll) {
      const container = findDOMNode(this)
      setTimeout(() => {
        scrollIntoView(container, menuContainer, {
          alignWithTop: false,
          offsetBottom: 5,
          onlyScrollIfNeeded: true
        })
      }, 0)
    }
  }

  beforeItemClick = e => {
    e.preventDefault()
    let { onClick } = this.props
    onClick()
  }

  render() {
    const {
      position,
      activeIndex,
      selected,
      label
    } = this.props
    return (
      <div
        role='button'
        tabIndex='0'
        className={`pk-select--dropdown_item has-hover-effect${(activeIndex === position) ? ' item-active' : ''}${selected ? ' item-selected' : ''}`}
        onClick={this.beforeItemClick}
      >
        <span className='pk-select--dropdown_item-text'>{label}</span>
      </div>
    )
  }
}

MenuItem.propTypes = {
  position: PropTypes.number,
  activeIndex: PropTypes.number,
  selected: PropTypes.bool,
  label: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
  menuContainer: PropTypes.any,
  onClick: PropTypes.func,
  autoScroll: PropTypes.bool,
}

export default MenuItem
